export_global

Macro export_global 

macro_rules! export_global {
    (static REGISTRY: $ty:ty = $init:expr;) => { ... };
}
export_global! { static REGISTRY: ty = expr; } exports the provided registry as the global registry singleton.

This macro must only be used at most once in every binary or shared library.