pub struct GlobalRegistry;Expand description
Global registry singleton.
If the global registry is used, its backing registry must be provided
exactly once using export_global.
The global registry must not be used to provide the backing of itself, which would result in an infinite loop at runtime.
Implementations
Sourceimpl GlobalRegistry
impl GlobalRegistry
Sourcepub fn codec_from_config<'de, D: Deserializer<'de>>(
config: D,
) -> Result<ErasedDynCodec, D::Error>
pub fn codec_from_config<'de, D: Deserializer<'de>>( config: D, ) -> Result<ErasedDynCodec, D::Error>
Deserialize an ErasedDynCodec from its config by looking up the
codec id in the GlobalRegistry.
The config must include the id field with the
[DynCodecType::codec_id].
Errors
Errors if no codec with a matching id has been registered, or if
constructing the codec fails.